=======
History
=======

0.1.0 (2019-04-14)
------------------

* First super-unpolished and barely usable release on PyPI.


0.3.0 (2019-06-26)
------------------

* First real release on PyPI.


0.4.0 (2019-11-12)
------------------

* Fixed multipage OCR on PDFs
* Added Language as a command line option


0.5.0 (2019-11-14)
------------------

* Removed unidecode function on OCR, no longer needed


0.6.0 (2019-11-14)
------------------

* Cleaned up PDF reading function
* Syncronized versioning


0.7.0 (2019-11-14)
------------------

* Nothing of consequence


0.8.0 (2019-11-14)
------------------

* Added --version flag on cli


1.2.0 (2019-11-14)
------------------

* Resolved failed builds related to bumpversion and
  manual versioning out of sync


1.3.0 (2019-12-03)
------------------

* Added special processing to turn CSVs into markdown tables


1.4.0 (2020-02-19)
------------------

* Ignore .part files (KDE Bug)
* Added logic to automatically assign tags to newly created notes
* Added click option to turn off automatic tag generation


1.5.0 (2020-02-19)
------------------

* Embarrassingly dumb bug fix for autotag argument
